//
//  GameController.m
//  Auto Layout demo
//
//  Created by Bertils mini on 2013-11-23.
//  Copyright (c) 2013-14 Sork Software. All rights reserved.
//

#import "DemoController.h"
#import "PlayerCentral.h"
#import "TitleView.h"
#import "SSMotionEffectSimple.h"

NSString *MoveNotification = @"Text Moved";

@implementation DemoController

#pragma mark - View lifecycle

- (void)viewDidLoad {
  [super viewDidLoad];
    
  /* The views involved
   GameController subviews
   "<PlayerCentral: 0x899cbe0; frame = (224 352; 320 320); autoresize = W+H; tag = 4; layer = <CALayer: 0x899ccb0>>",
   "<UIButton: 0x899ab10; frame = (361 894; 72 41); opaque = NO; autoresize = RM+BM; layer = <CALayer: 0x899ac60>>",
   "<_UILayoutGuide: 0xa1d3320; frame = (0 0; 0 0); hidden = YES; layer = <CALayer: 0xa1ce0f0>>",
   "<_UILayoutGuide: 0xa1d3630; frame = (0 0; 0 0); hidden = YES; layer = <CALayer: 0xa1d2650>>"
   
   PlayerCentral subviews
   "<PlayerViewContainer: 0x7c20e9e0; frame = (0 273; 273 47); autoresize = RM+BM; layer = <CALayer: 0x7c20eb70>>",
   "<PlayerViewContainer: 0x7c20f070; frame = (273 47; 47 273); autoresize = RM+BM; tag = 1; layer = <CALayer: 0x7c20f0e0>>",
   "<PlayerViewContainer: 0x7c20f170; frame = (47 0; 273 47); autoresize = RM+BM; tag = 2; layer = <CALayer: 0x7c20f1e0>>",
   "<PlayerViewContainer: 0x7c20f320; frame = (0 0; 47 273); autoresize = RM+BM; tag = 3; layer = <CALayer: 0x7c20f390>>",
   "<PlaceView: 0x7c20f560; frame = (47 47; 226 226); autoresize = RM+BM; tag = 5; layer = <CALayer: 0x7c20f6f0>>"
   
   "<NSLayoutConstraint:0x7c20faa0 H:[PlayerCentral:0x7c20e600(320)]>",
   "<NSLayoutConstraint:0x7c20fad0 V:[PlayerCentral:0x7c20e600(320)]>",
   "<NSLayoutConstraint:0x7c20fb00 V:|-(0)-[PlayerViewContainer:0x7c20f320]   (Names: '|':PlayerCentral:0x7c20e600 )>",
   "<NSLayoutConstraint:0x7c20fb30 H:|-(0)-[PlayerViewContainer:0x7c20f320]   (Names: '|':PlayerCentral:0x7c20e600 )>",
   "<NSLayoutConstraint:0x7c20fb60 H:[PlayerViewContainer:0x7c20f170]-(0)-|   (Names: '|':PlayerCentral:0x7c20e600 )>",
   "<NSLayoutConstraint:0x7c20fb90 V:|-(0)-[PlayerViewContainer:0x7c20f170]   (Names: '|':PlayerCentral:0x7c20e600 )>",
   "<NSLayoutConstraint:0x7c20fbc0 H:[PlayerViewContainer:0x7c20f320]-(0)-[PlayerViewContainer:0x7c20f170]>",
   "<NSLayoutConstraint:0x7c20fbf0 V:[PlayerViewContainer:0x7c20f170]-(0)-[PlaceView:0x7c20f560]>",
   "<NSLayoutConstraint:0x7c20fc20 PlayerCentral:0x7c20e600.centerX == PlaceView:0x7c20f560.centerX>",
   "<NSLayoutConstraint:0x7c20fc50 H:[PlayerViewContainer:0x7c20f320]-(0)-[PlaceView:0x7c20f560]>",
   "<NSLayoutConstraint:0x7c20fc80 PlayerCentral:0x7c20e600.centerY == PlaceView:0x7c20f560.centerY>",
   "<NSLayoutConstraint:0x7c20fcb0 V:[PlaceView:0x7c20f560]-(0)-[PlayerViewContainer:0x7c20e9e0]>",
   "<NSLayoutConstraint:0x7c20fce0 H:|-(0)-[PlayerViewContainer:0x7c20e9e0]   (Names: '|':PlayerCentral:0x7c20e600 )>",
   "<NSLayoutConstraint:0x7c20fd10 V:[PlayerViewContainer:0x7c20e9e0]-(0)-|   (Names: '|':PlayerCentral:0x7c20e600 )>",
   "<NSLayoutConstraint:0x7c20fd40 V:[PlayerViewContainer:0x7c20f320]-(0)-[PlayerViewContainer:0x7c20e9e0]>",
   "<NSLayoutConstraint:0x7c20fd70 H:[PlaceView:0x7c20f560]-(0)-[PlayerViewContainer:0x7c20f070]>",
   "<NSLayoutConstraint:0x7c20fda0 H:[PlayerViewContainer:0x7c20e9e0]-(0)-[PlayerViewContainer:0x7c20f070]>",
   "<NSLayoutConstraint:0x7c20fdd0 V:[PlayerViewContainer:0x7c20f170]-(0)-[PlayerViewContainer:0x7c20f070]>",
   "<NSLayoutConstraint:0x7c20fe00 V:[PlayerViewContainer:0x7c20f070]-(0)-|   (Names: '|':PlayerCentral:0x7c20e600 )>",
   "<NSLayoutConstraint:0x7c20fe30 H:[PlayerViewContainer:0x7c20f070]-(0)-|   (Names: '|':PlayerCentral:0x7c20e600 )>"
   */
  
  // Create our simplistic ME subclass thingy and add it to the titleView
  [self.largeTitle addMotionEffect:[[SSMotionEffectSimple alloc] init]];
  
  // Listen to notifications from the ME subclass and update the titleView
  [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(deviceMoved:)
                                               name:MoveNotification object:nil];
  
  [self.playerCentral loadPlayerViews];
}

#pragma mark - Notifications

// The user moved the device
- (void)deviceMoved:(NSNotification *)notification {
	// Get the move from the notifications userInfo
  NSValue *theMove = [[notification userInfo] objectForKey:@"Offset"];
  CGPoint thePoint = [theMove CGPointValue];
  
  // Update the drawing with the new offsets
  self.largeTitle.offsets = thePoint;
  
  [self.largeTitle setNeedsDisplay];
}

#pragma mark - Action methods

// Toggle the central size between the iPhone's 320 px and something slightly larger
- (IBAction)toggleLayout:(UIButton *)sender
{
  NSArray *pcCons = self.playerCentral.constraints;
  NSLayoutConstraint *aCon;
  CGFloat newSize = 375; // iPhone 6
  
  for (aCon in pcCons)
  {
    if (aCon.firstAttribute == NSLayoutAttributeWidth)
    {
      if (aCon.constant == 320) {
        aCon.constant = newSize;
      }
      else {
        aCon.constant = 320;
      }
    }
    if (aCon.firstAttribute == NSLayoutAttributeHeight)
    {
      if (aCon.constant == 320) {
        aCon.constant = newSize;
      }
      else {
        aCon.constant = 320;
      }
    }
  }
}

@end
