//
//  PlayerView.m
//  Auto Layout demo
//
//  Holds a LED lamp, a static player name and a dynamic score count
//
//  Created by Bertils mini on 2010-01-16.
//  Copyright 2010-14 Sork Software. All rights reserved.
//  Version 1.2 modifies layoutSubviews with corrections for the problems added by iOS8. Nov 2014
//

#import "PlayerView.h"
#import "PlayerViewContainer.h"

@implementation PlayerView

// In the Player View the background tag is 10, the indicator 11, the label 12, and the score 13
- (id)initWithCoder:(NSCoder*)coder {
	if (self = [super initWithCoder:coder]) {
    //self.translatesAutoresizingMaskIntoConstraints = NO;
    
    UIView *backView = [self viewWithTag:10];
    self.backSize = backView.frame.size; // {273, 47}

    UIView *labelView = [self viewWithTag:12];
    self.titleSize = labelView.frame.size; // {136, 28}

    UIView *scoreView = [self viewWithTag:13];
    self.scoreSize = scoreView.frame.size; // {70, 46}
  }
	return self;
}

/* PV constraints added in IB
 "<NSLayoutConstraint:0x7b84c700 V:[UIImageView:0x7b847e40]-(0)-|   (Names: '|':PlayerView:0x7b8479e0 )>",
 "<NSLayoutConstraint:0x7b84c730 H:|-(0)-[UIImageView:0x7b847e40]   (Names: '|':PlayerView:0x7b8479e0 )>",
 "<NSLayoutConstraint:0x7b84c760 H:[UIImageView:0x7b847e40]-(0)-|   (Names: '|':PlayerView:0x7b8479e0 )>",
 "<NSLayoutConstraint:0x7b84c790 V:|-(0)-[UIImageView:0x7b847e40]   (Names: '|':PlayerView:0x7b8479e0 )>",
 "<NSLayoutConstraint:0x7b84c7c0 H:|-(0)-[UIImageView:0x7b849540]   (Names: '|':PlayerView:0x7b8479e0 )>",
 "<NSLayoutConstraint:0x7b84c7f0 PlayerView:0x7b8479e0.centerY == UIImageView:0x7b849540.centerY>",
 "<NSLayoutConstraint:0x7b84c820 PlayerView:0x7b8479e0.centerY == UILabel:0x7b849f00'Player bar'.centerY>",
 "<NSLayoutConstraint:0x7b84c850 H:[UIImageView:0x7b849540]-(NSSpace(8))-[UILabel:0x7b849f00'Player bar']>",
 "<NSLayoutConstraint:0x7b84c8a0 V:|-(3)-[UILabel:0x7b84b430'000']   (Names: '|':PlayerView:0x7b8479e0 )>",
 "<NSLayoutConstraint:0x7b84c8d0 H:[UILabel:0x7b849f00'Player bar']-(NSSpace(8))-[UILabel:0x7b84b430'000']>",
 "<NSLayoutConstraint:0x7b84c900 V:[UILabel:0x7b84b430'000']-(-2)-|   (Names: '|':PlayerView:0x7b8479e0 )>",
 "<NSLayoutConstraint:0x7b84c930 H:[UILabel:0x7b84b430'000']-(8)-|   (Names: '|':PlayerView:0x7b8479e0 )>"
 
 // Background
 "<NSContentSizeLayoutConstraint:0x79788860 H:[UIImageView:0x79637ab0(272)] Hug:250 CompressionResistance:750>",
 "<NSContentSizeLayoutConstraint:0x797889a0 V:[UIImageView:0x79637ab0(46)] Hug:250 CompressionResistance:750>"

 // Indicator
 "<NSContentSizeLayoutConstraint:0x7bac8540 H:[UIImageView:0x7baae890(47)] Hug:251 CompressionResistance:750>",
 "<NSContentSizeLayoutConstraint:0x7bac8860 V:[UIImageView:0x7baae890(47)] Hug:250 CompressionResistance:750>"

 // Player label
 "<NSContentSizeLayoutConstraint:0x7b0434f0 H:[UILabel:0x7b1315f0'South \U5357'(99)] Hug:249 CompressionResistance:749>",
 "<NSContentSizeLayoutConstraint:0x7b025ad0 V:[UILabel:0x7b1315f0'South \U5357'(28)] Hug:250 CompressionResistance:750>"

 // Score label
 "<NSLayoutConstraint:0x7ae64470 H:[UILabel:0x7ae644f0'000'(70@750)] priority:750>",
 "<NSContentSizeLayoutConstraint:0x7b976200 H:[UILabel:0x7ae644f0'000'(70)] Hug:251 CompressionResistance:750>",
 "<NSContentSizeLayoutConstraint:0x7b976240 V:[UILabel:0x7ae644f0'000'(36)] Hug:250 CompressionResistance:750>"
*/

// Correct the frames that are mangled by Auto Layout in OS 8
// Adjusts the indicator lamp subview horizontal position when the view width changes
- (void)layoutSubviews {
  [super layoutSubviews];
  
  // Correct the player view frame by copying the containing frame hor/ver
  UIView *conView = [self superview];
  CGRect conFrame = CGRectMake(0.0, 0.0, conView.frame.size.width, conView.frame.size.height);
  self.frame = conFrame; // {{0, 0}, {273, 47}}, {{0, 0}, {300, 75}}

  // Get the basic player view size from its current container size independent of rotation
  CGSize baseSize = [(PlayerViewContainer *)conView basicPlayerViewSize]; // {273, 47}, {300, 75}
  // The app version could use the backSize instead, ie the background highlight view size
  
  // Use the basic size to frame the player view background view image
  CGRect highFrame = CGRectMake(0.0, 0.0, baseSize.width, baseSize.height);
  self.playerHighlight.frame = highFrame;
  
  // Calculate the ver and hor offset of the lamp view
  CGFloat lampOffset = (highFrame.size.height - self.playerIndicator.frame.size.height) / 2;
  CGRect lampFrame = CGRectMake(lampOffset, lampOffset, 47.0, 47.0);
  self.playerIndicator.frame = lampFrame;
  
  // Calculate the correct position for the score label and adjust its font size
  UIFont *scoreFont;
  if (baseSize.height > 47.0) {
    scoreFont = [UIFont fontWithName:@"DBLCDTempBlack" size:45]; // char height 72
  } else {
    scoreFont = [UIFont fontWithName:@"DBLCDTempBlack" size:36]; // char height 58
  }
  self.scoreLabel.font = scoreFont;
  
  CGFloat scoreHorPos = baseSize.width - self.scoreSize.width - 8.0;
  CGFloat scoreVerPos = 3.5 + (baseSize.height - self.scoreSize.height) / 2;
  CGRect scoreFrame = CGRectMake(scoreHorPos, scoreVerPos, self.scoreSize.width, self.scoreSize.height);
  self.scoreLabel.frame = scoreFrame; // {178, 4}, {87, 45}, {205, 17.5}, {87, 45}

  // Adjust the size and position of the player title label and adjust its font size
  UIFont *playerFont;
  if (baseSize.height > 47.0) {
    playerFont = [UIFont boldSystemFontOfSize:31];
  } else {
    playerFont = [UIFont boldSystemFontOfSize:25];
  }
  self.playerLabel.font = playerFont;
  
  CGFloat titleVerPos = (baseSize.height - self.titleSize.height) / 2; // 9.5
  CGFloat titleHorPos = self.playerIndicator.frame.size.width + self.playerIndicator.frame.origin.x + 8.0; // 55/69
  CGRect titleFrame = CGRectMake(titleHorPos, titleVerPos, self.titleSize.width, self.titleSize.height);
  self.playerLabel.frame = titleFrame; // {55, 9.5}, {136, 28}, {69, 23.5}, {136, 28}
  
  // Lay out the adjusted subviews again
  [self layoutIfNeeded];
}

@end
